pitchtools.is_chromatic_pitch_class_number
==========================================

.. autofunction:: abjad.tools.pitchtools.is_chromatic_pitch_class_number.is_chromatic_pitch_class_number
   :noindex:
